ConsoleOutput class

Pretty-prints log records to stdout with optional ANSI colors.

Inheritance

Constructors

ConsoleOutput({bool colored = true, ConsoleFormat format = ConsoleFormat.pretty, String? scopeFilter})

Properties

colored bool
Whether to use ANSI color codes.
final
format ConsoleFormat
Output format.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scopeFilter String?
Optional scope filter. If non-null, this output only receives records whose scope starts with this prefix.
final

Methods

dispose() → void
Clean up resources.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
write(LogRecord record) → void
Write a log record (event or span).
override

Operators

operator ==(Object other) bool
The equality operator.
inherited