LogConfig class

Snapshot of controller configuration (for remote control / diagnostics).

Constructors

LogConfig({required RpcLogLevel minLevel, Map<String, RpcLogLevel> scopeLevels = const {}, Map<String, RpcLogLevel> tagLevels = const {}})
Creates a LogConfig snapshot.
const
LogConfig.fromJson(Map<String, dynamic> json)
Deserializes a LogConfig from a JSON-compatible map.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
minLevel RpcLogLevel
Global minimum log level.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scopeLevels Map<String, RpcLogLevel>
Per-scope level overrides.
final
tagLevels Map<String, RpcLogLevel>
Per-tag level overrides.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this config to a JSON-compatible map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited