LogFormattingResult class

Formatting result split into header and content.

Constructors

LogFormattingResult(String header, String content)
Creates a result with header and content.

Properties

content String
Message body content.
final
hashCode int
The hash code for this object.
no setterinherited
Message header.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited