RpcEndpointPingProtocol class abstract final

Ping protocol constants and metadata between endpoints.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

methodKey → const String
Method key in service.method form.
methodName → const String
Method name for ping requests.
methodPath → const String
HTTP/2 path /Service/Method.
requestTimestampHeader → const String
Header with client ping timestamp.
responseDebugLabelHeader → const String
Header with responder endpoint debug label.
responseTimestampHeader → const String
Header with responder processing timestamp.
responseTransportHeader → const String
Header with responder transport type.
serviceName → const String
Service name for ping requests.