DefaultRpcLoggerFilter class
Default filter based on minimum log level.
- Implemented types
Constructors
- DefaultRpcLoggerFilter(RpcLoggerLevel minLogLevel)
-
Creates a filter that passes messages at or above
minLogLevel.const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- minLogLevel → RpcLoggerLevel
-
Minimum level that will be logged; messages below this are suppressed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldLog(
RpcLoggerLevel level, String source) → bool -
Returns true if the message should be logged for the given level/source.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited