DefaultRpcLoggerFormatter class
Default log formatter.
- Implemented types
Constructors
- DefaultRpcLoggerFormatter([String? label])
-
Creates a formatter with an optional
label.const
Properties
Methods
-
format(
DateTime timestamp, RpcLoggerLevel level, String source, String message, {String? context, String? requestId, String? traceId}) → LogFormattingResult -
Formats a log entry, returning header and content separately.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited