IRpcCodec<T> class
abstract
Contract for encoding and decoding messages.
Hides the underlying serialization format (JSON, Protocol Buffers, MessagePack, etc.) while providing conversion to and from bytes.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deserialize(
Uint8List bytes) → T - Deserializes bytes into an object of type T.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
T message) → Uint8List - Serializes an object of type T to a byte sequence.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited