LogConfig class

Snapshot of controller configuration (for remote control / diagnostics).

Constructors

LogConfig({required RpcLogLevel minLevel, Map<String, RpcLogLevel> scopeLevels = const {}, Map<String, RpcLogLevel> tagLevels = const {}})
const
LogConfig.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
minLevel RpcLogLevel
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scopeLevels Map<String, RpcLogLevel>
final
tagLevels Map<String, RpcLogLevel>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited