LogEvent class
A point-in-time log event.
- Implemented types
Constructors
Properties
-
data
→ Map<
String, Object> ? -
Structured metadata.
final
- error → Object?
-
Error object (for error/fatal levels).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- level → RpcLogLevel
-
Severity level.
final
- message → String
-
Human-readable message.
final
- requestId → String?
-
RPC request correlation ID.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scope → String
-
Scope name (e.g. 'rpc.transport.router').
final
- spanId → String?
-
Span ID if this event occurred inside a span.
final
- stackTrace → StackTrace?
-
Stack trace (for error/fatal levels).
final
- tag → String?
-
Optional sub-category for filtering.
final
- timestamp → DateTime
-
When this record was created.
final
- traceId → String?
-
RPC trace correlation ID.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited