LogFilter class
Filter criteria for log subscriptions and queries.
Used by RPC log service for remote filtering (filtering at source to reduce traffic).
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- minLevel → RpcLogLevel?
-
Minimum level to include.
final
- requestId → String?
-
Only include records with this request ID.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scopes
→ Set<
String> ? -
Only include records from scopes starting with these prefixes.
final
-
Only include records with these tags.
final
- traceId → String?
-
Only include records with this trace ID.
final
Methods
-
matches(
{required RpcLogLevel level, required String scope, String? tag, String? traceId, String? requestId}) → bool - Check if a record matches this filter.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Serializes this filter to a JSON-compatible map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited