LogSpanStart class
Marks the beginning of a span.
- Implemented types
Constructors
- LogSpanStart({required String spanId, required String scope, required String name, DateTime? timestamp})
Properties
-
data
→ Map<
String, Object> ? -
Structured metadata.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Operation name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scope → String
-
Scope name (e.g. 'rpc.transport.router').
final
- spanId → String
-
Span identifier (matches the LogSpan.spanId emitted on end).
final
- timestamp → DateTime
-
When this record was created.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited