RpcResponderStreamStore class final
Manages the set of active RpcResponderStreamState instances.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- length → int
-
Number of active streams.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
values
→ Iterable<
RpcResponderStreamState> -
All active stream states.
no setter
Methods
-
clear(
) → void - Removes all active stream states.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
obtain(
int streamId) → RpcResponderStreamState -
Returns or creates the stream state for
streamId. -
take(
int streamId) → RpcResponderStreamState? -
Removes and returns the stream state for
streamId. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
int streamId) → RpcResponderStreamState? -
Returns the stream state for
streamId, or null if absent.