SamplingConfig class
Per-level sampling configuration.
Limits the number of log records per level within a time interval. Records above the limit are dropped. Levels not in maxPerInterval are unlimited.
Constructors
-
SamplingConfig({Duration interval = const Duration(seconds: 1), Map<
RpcLogLevel, int> maxPerInterval = const {}}) -
Creates a sampling configuration with the given limits and time window.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- interval → Duration
-
Time window for counting records.
final
-
maxPerInterval
→ Map<
RpcLogLevel, int> -
Maximum records to keep per level per interval.
Levels not in this map are unlimited.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited