SamplingState class
Runtime sampling state that tracks record counts per level within the current interval.
Constructors
- SamplingState(SamplingConfig config)
-
Creates sampling state for the given
config.
Properties
- config → SamplingConfig
-
The sampling configuration used by this state.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldKeep(
RpcLogLevel level) → bool - Returns true if the record should be kept (not sampled out).
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited